@@ -10,8 +10,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.concurrent.TimeUnit;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import org.codehaus.jackson.JsonEncoding;
 import org.codehaus.jackson.JsonFactory;
 import org.codehaus.jackson.JsonGenerator;
@@ -29,7 +29,10 @@ import org.ovirt.vdsm.jsonrpc.client.ResponseBuilder;
  */
 public class JsonUtils {
     public static final Charset UTF8 = Charset.forName("UTF-8");
-    private static Log log = LogFactory.getLog(JsonUtils.class);
+    private static final double GRACE_PERIOD = 0.2;
+    public static final String ALL = "*";
+    public static final String SUBSCRIPTION_ALL = "*|*|*|*";
+    private static Logger log = LoggerFactory.getLogger(JsonUtils.class);
     private static ObjectMapper mapper = new ObjectMapper();
     private static JsonFactory factory = mapper.getJsonFactory();
     static {
@@ -110,18 +113,35 @@ public class JsonUtils {
     }
 
     public static int reduceGracePeriod(int interval) {
-        return interval - (int) (interval * 0.1);
+        return interval - (int) (interval * GRACE_PERIOD);
+    }
+
+    public static int addGracePeriod(int interval) {
+        return interval + (int) (interval * GRACE_PERIOD);
+    }
+
+    public static String swapHeartbeat(String heartbeat) {
+        String[] heartbeats = heartbeat.split(",");
+        return heartbeats[1] + "," + heartbeats[0];
     }
 
     public static long getTimeout(int timeout, TimeUnit unit) {
         return new Date().getTime() + TimeUnit.MILLISECONDS.convert(timeout, unit);
     }
 
-    public static void logException(Log logger, String message, Throwable throwable) {
+    public static void logException(Logger logger, String message, Throwable throwable) {
         if (logger.isDebugEnabled()) {
             logger.debug(message, throwable);
         } else {
             logger.error(message);
         }
     }
+
+    public static String[] parse(String id) {
+        String[] ids = id.split("\\|");
+        if (ids == null || ids.length == 0 || ids.length != 4) {
+            throw new IllegalArgumentException("wrong id format");
+        }
+        return ids;
+    }
 }
