@@ -2,11 +2,13 @@ package org.ovirt.vdsm.jsonrpc.client.utils.retry;
 
 import java.io.IOException;
 
+import org.ovirt.vdsm.jsonrpc.client.internal.ClientPolicy;
+
 /**
  * Default implementation of connection level retry functionality.
  *
  */
-public class DefaultConnectionRetryPolicy extends RetryPolicy {
+public class DefaultConnectionRetryPolicy extends ClientPolicy {
     public DefaultConnectionRetryPolicy() {
         super(2000, 0, 10000, IOException.class);
     }
