@@ -1,12 +1,17 @@
 package org.ovirt.vdsm.jsonrpc.client.reactors.stomp;
 
 import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.fail;
+import static org.ovirt.vdsm.jsonrpc.client.reactors.stomp.StompCommonClient.DEFAULT_REQUEST_QUEUE;
+import static org.ovirt.vdsm.jsonrpc.client.reactors.stomp.StompCommonClient.DEFAULT_RESPONSE_QUEUE;
 import static org.ovirt.vdsm.jsonrpc.client.utils.JsonUtils.UTF8;
 
 import java.io.IOException;
 import java.security.GeneralSecurityException;
+import java.security.cert.Certificate;
+import java.util.List;
 import java.util.Random;
 import java.util.concurrent.ArrayBlockingQueue;
 import java.util.concurrent.BlockingQueue;
@@ -26,7 +31,6 @@ import org.ovirt.vdsm.jsonrpc.client.reactors.ReactorClient;
 import org.ovirt.vdsm.jsonrpc.client.reactors.ReactorClient.MessageListener;
 import org.ovirt.vdsm.jsonrpc.client.reactors.ReactorListener;
 import org.ovirt.vdsm.jsonrpc.client.reactors.ReactorListener.EventListener;
-import org.ovirt.vdsm.jsonrpc.client.utils.retry.RetryPolicy;
 
 public class SSLStompClientTestCase {
     private static final String CHAR_LIST = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ1234567890";
@@ -41,10 +45,7 @@ public class SSLStompClientTestCase {
 
     @Before
     public void setUp() throws IOException, GeneralSecurityException {
-        this.provider =
-                new TestManagerProvider(ClassLoader.getSystemResourceAsStream(KEYSTORE_NAME),
-                        ClassLoader.getSystemResourceAsStream(TRUSTSTORE_NAME),
-                        PASSWORD);
+        this.provider = createProvider();
         SSLContext context = this.provider.getSSLContext();
         this.listeningReactor = new SSLStompReactor(context);
         this.sendingReactor = new SSLStompReactor(context);
@@ -59,12 +60,14 @@ public class SSLStompClientTestCase {
     }
 
     @Test
-    public void testShortMessage() throws InterruptedException, ExecutionException, ClientConnectionException {
+    public void testShortMessage() throws InterruptedException, ExecutionException, ClientConnectionException,
+            IllegalAccessException {
         testEcho(generateRandomMessage(16));
     }
 
     @Test
-    public void testLongMessage() throws InterruptedException, ExecutionException, ClientConnectionException {
+    public void testLongMessage() throws InterruptedException, ExecutionException, ClientConnectionException,
+            IllegalAccessException {
         testEcho(generateRandomMessage(524288));
     }
 
@@ -74,7 +77,7 @@ public class SSLStompClientTestCase {
         int port = 60627;
         final BlockingQueue<byte[]> queue = new ArrayBlockingQueue<>(5);
         ReactorClient client = this.sendingReactor.createClient(HOSTNAME, port);
-        client.setRetryPolicy(new RetryPolicy(180000, 0, 1000000));
+        client.setClientPolicy(new StompClientPolicy(180000, 0, 1000000, DEFAULT_REQUEST_QUEUE, DEFAULT_RESPONSE_QUEUE));
         client.addEventListener(new ReactorClient.MessageListener() {
 
             @Override
@@ -125,7 +128,7 @@ public class SSLStompClientTestCase {
     public static String generateRandomMessage(int length) {
         Random random = new Random();
         StringBuffer randStr = new StringBuffer();
-        for(int i=0; i< length; i++){
+        for (int i = 0; i < length; i++) {
             int number = random.nextInt(CHAR_LIST.length());
             char ch = CHAR_LIST.charAt(number);
             randStr.append(ch);
@@ -133,7 +136,14 @@ public class SSLStompClientTestCase {
         return randStr.toString();
     }
 
-    public void testEcho(String message) throws InterruptedException, ExecutionException, ClientConnectionException {
+    public static TestManagerProvider createProvider() {
+        return new TestManagerProvider(ClassLoader.getSystemResourceAsStream(KEYSTORE_NAME),
+                ClassLoader.getSystemResourceAsStream(TRUSTSTORE_NAME),
+                PASSWORD);
+    }
+
+    public void testEcho(String message) throws InterruptedException, ExecutionException, ClientConnectionException,
+            IllegalAccessException {
         final BlockingQueue<byte[]> queue = new ArrayBlockingQueue<>(5);
         Future<ReactorListener> futureListener =
                 this.listeningReactor.createListener(HOSTNAME, 0, new EventListener() {
@@ -157,7 +167,7 @@ public class SSLStompClientTestCase {
         assertNotNull(listener);
 
         ReactorClient client = this.sendingReactor.createClient(HOSTNAME, listener.getPort());
-        client.setRetryPolicy(new RetryPolicy(180000, 0, 1000000));
+        client.setClientPolicy(new StompClientPolicy(180000, 0, 1000000, DEFAULT_REQUEST_QUEUE, DEFAULT_RESPONSE_QUEUE));
         client.addEventListener(new ReactorClient.MessageListener() {
 
             @Override
@@ -176,6 +186,10 @@ public class SSLStompClientTestCase {
         client.sendMessage(message.getBytes());
         response = queue.poll(TIMEOUT_SEC, TimeUnit.SECONDS);
 
+        List<Certificate> peerCertificates = client.getPeerCertificates();
+        assertNotNull(peerCertificates);
+        assertFalse(peerCertificates.isEmpty());
+
         client.close();
         listener.close();
 
